Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3818)

Unified Diff: chrome/common/child_process_logging_win.cc

Issue 365133005: Refactor SetClientID such that metrics rather than crash backs up the client id in Google Update set (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: nits:grt Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/metrics/chrome_metrics_service_client.cc ('k') | chrome/common/crash_keys.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/child_process_logging_win.cc
diff --git a/chrome/common/child_process_logging_win.cc b/chrome/common/child_process_logging_win.cc
index 1befb33b23a2eb971ddecee0e1c277a40b51e471..b849734250a83d636f701de590117c50bf41544a 100644
--- a/chrome/common/child_process_logging_win.cc
+++ b/chrome/common/child_process_logging_win.cc
@@ -65,12 +65,13 @@ void Init() {
base::debug::SetCrashKeyReportingFunctions(
&SetCrashKeyValueTrampoline, &ClearCrashKeyValueTrampoline);
- // This would be handled by BreakpadClient::SetClientID(), but because of the
- // aforementioned issue, crash keys aren't ready yet at the time of Breakpad
- // initialization.
- std::string client_id;
- if (GoogleUpdateSettings::GetMetricsId(&client_id))
- base::debug::SetCrashKeyValue(crash_keys::kClientID, client_id);
+ // This would be handled by BreakpadClient::SetCrashClientIdFromGUID(), but
+ // because of the aforementioned issue, crash keys aren't ready yet at the
+ // time of Breakpad initialization, load the client id backed up in Google
+ // Update settings instead.
+ std::string client_guid;
+ if (GoogleUpdateSettings::LoadMetricsClientId(&client_guid))
+ crash_keys::SetCrashClientIdFromGUID(client_guid);
}
} // namespace child_process_logging
« no previous file with comments | « chrome/browser/metrics/chrome_metrics_service_client.cc ('k') | chrome/common/crash_keys.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698